// pages/login/phone-register/index.js
import {
  sendPhoneCode
} from '~/services/login/phone-register';
import {
  login
} from '~/services/login/login';
import Toast from '~/miniprogram_npm/@vant/weapp/toast/toast';

Page({

  /**
   * 页面的初始数据
   */
  data: {
    logoImg: "https://tool.aerwen.net/prod-api/Open/20230602/8969EAF2294B1FF4.png",
    phoneNumber: "", //手机号
    phoneError: false, // 手机号验证
    verifyCode: "", //验证码
  },


  /** 发送验证码 */
  send() {
    if (!this.data.phoneNumber) {
      wx.showToast({
        icon: 'error',
        title: '请输入手机号',
      });
      return;
    }
    const isPhoneNumber = /^[1][3,4,5,7,8,9][0-9]{9}$/.test(this.data.phoneNumber);
    if (!isPhoneNumber) {
      wx.showToast({
        icon: 'error',
        title: '手机号格式不正确',
      });
      return;
    }

    let data = {
      PhoneNumber: this.data.phoneNumber,
    }
    sendPhoneCode(data)
  },


  /** 手机号验证 */
  onPhoneInput(e) {
    const {
      phoneError
    } = this.data;
    const isPhoneNumber = /^[1][3,4,5,7,8,9][0-9]{9}$/.test(e.detail.value);
    if (phoneError === isPhoneNumber) {
      this.setData({
        phoneError: !isPhoneNumber,
        phoneNumber: e.detail.value,
      });
    }
  },

  /** 用户名 */
  onNameInput(e) {
    this.setData({
      phoneNumber: e.detail.value,
    });
  },

  /** 密码 */
  onPasswordInput(e) {
    this.setData({
      verifyCode: e.detail.value,
    });
  },


  toLogin(e) {
    let {
      phoneNumber,
      verifyCode
    } = this.data

    // console.log(phoneNumber, '用户名');
    // console.log(verifyCode, '密码');

    if (!phoneNumber) {
      wx.showToast({
        title: '请输入用户名',
        icon: 'error',
        duration: 2000
      })
      return
    }
    if (!verifyCode) {
      wx.showToast({
        title: '请输入密码',
        icon: 'error',
        duration: 2000
      })
      return
    }

    let data = {
      CustomerNickname: phoneNumber,
      CustomerPassword: verifyCode
    }

    // 登录请求
    login(data).then((res) => {
      if (res.code === 200) {
        setTimeout(() => {
          wx.showToast({
            icon: 'success',
            title: '登录成功',
          });
        }, 1000);
        wx.switchTab({
          url: '/pages/home/home',
        });
      }
    })
  },


  /**
   * 生命周期函数--监听页面加载
   */
  onLoad(options) {

  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady() {

  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow() {

  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide() {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload() {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh() {

  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom() {

  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage() {

  }
})